@@ -1,7 +1,8 @@
-//! Graphql Tools
+//! graphql-tools
 //! ==============
 //!
-//!
+//! This library implements tooling around GraphQL for Rust libraries. 
+//! Most of the tools are based on `trait`s and `struct`s implemented in `graphql_parser` crate.
 //!
 
 pub mod ast;
@@ -27,7 +28,7 @@ pub mod static_graphql {
     static_graphql!(schema, schema, {
       Field, Directive, InterfaceType, ObjectType, Value, TypeDefinition,
       EnumType, Type, Document, ScalarType, InputValue, DirectiveDefinition,
-      UnionType, InputObjectType, EnumValue,
+      UnionType, InputObjectType, EnumValue, SchemaDefinition,
     });
 }
 
