@@ -1,7 +1,7 @@
 use crate::validation::utils::ValidationContext;
 
 pub trait ValidationRule: Send + Sync {
-    fn validate(&self, _ctx: &mut ValidationContext) {
+    fn validate(&self, _ctx: &mut ValidationContext) -> () {
         unimplemented!("Missing ValidationRule:validate implementation");
     }
 }
